from django.db import models


class SmartModule(models.Model):
    name = models.CharField(max_length=50, verbose_name='模块名称')
    device_id = models.CharField(max_length=100, verbose_name='模块ID')
    chip_id = models.CharField(max_length=100, verbose_name='单片机ID')

    class Meta:
        verbose_name = '智能模块'
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.name


class Mosquito(models.Model):
    name = models.CharField(max_length=100, verbose_name='设备名称')
    device_id = models.CharField(max_length=100, verbose_name='设备ID')
    smart_module = models.ForeignKey(SmartModule, on_delete='PROTECT')
    region = models.CharField(max_length=50, verbose_name='区域')

    class Meta:
        verbose_name = '灭蚊灯'
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.device_id

    def get_absolute_url(self):
        pass

    def get_api_url(self):
        pass


class MosqPost(models.Model):
    mosq = models.ForeignKey(Mosquito, verbose_name='灭蚊灯', on_delete='PROTECT')
    led = models.PositiveIntegerField(max_length=30, verbose_name='灭蚊数')
    energy = models.PositiveIntegerField(max_length=10, verbose_name='电量')
    signal = models.IntegerField(max_length=10, verbose_name='信号')
    times = models.DateTimeField(auto_now=False, auto_now_add=True)

    class Meta:
        verbose_name = '灭蚊数据'
        verbose_name_plural = verbose_name

    def __str__(self):
        return '{0}: {1}'.format(self.mosq.name, self.led)

    def get_api_url(self):
        pass
